Crate name_to_handle_at_rs

Crate name_to_handle_at_rs 

This crate provides bindings for name_to_handle_at() and open_by_handle_at() system calls in Linux

These system calls can be used to refer to i-nodes on the file system using a byte array that does not change during i-node lifetime

This crate can be useful for user-space NFS servers (since NFS protocols require such references) and fanotify users wanting to refer to watched files by handles

Structs

LinuxFileHandle
A struct representing the file handle. The file handle itself is stored on the heap, this struct only contains a pointer to it.
OpenFlags
Open flags for open_by_handle_at()